@@ -1,4 +1,5 @@
 import os
+import warnings
 from types import ModuleType
 from collections import defaultdict
 from warnings import warn
@@ -332,6 +333,20 @@ class InstalledPackage(Package):
                 doc.append('[R help was not found]')
         return os.linesep.join(doc)
 
+
+class WeakPackage(Package):
+    """
+    'Weak' R package, with which looking for symbols results in
+    a warning (and a None returned) whenever the desired symbol is
+    not found (rather than a traditional `AttributeError`).
+    """
+    
+    def __getattr__(self, name):
+        res =self.__dict__.get(name)
+        if res is None:
+            warnings.warn("The symbol '%s' is not in this R namespace/package." % name)
+        return res
+    
 class LibraryError(ImportError):
     """ Error occuring when importing an R library """
     pass
